==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgeditaliastrigger.h <==
/***************************************************************************
                          dlgeditaliastrigger.h  -  edit alias/trigger
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne sep 22 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITALIASTRIGGER_H
#define DLGEDITALIASTRIGGER_H

#include <qwidget.h>
#include <kdialogbase.h>

#include <config.h>

//needed to get some #define...
#include "../ctrigger.h"

class cAlias;
class cSession;

/**
Editor of one alas or trigger. Modifies itself depending on whether we're
editing an alias or a trigger...
  *@author Tomas Mecir
  */

class QButtonGroup;
class QCheckBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QListView;
class QPushButton;

class KColorButton;
class KGridView;
class KIntNumInput;
class KLineEdit;
class KTextEdit;

class dlgEditAliasTrigger : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditAliasTrigger (cAlias *a, cSession *s, QWidget *parent=0, const char *name=0);
  dlgEditAliasTrigger (cTrigger *t, cSession *s, QWidget *parent=0, const char *name=0);
  ~dlgEditAliasTrigger ();
  bool showMe ();
protected slots:
  void updateEditButton (const QString &comboText);
  void editRegExp ();
  void updateTest (const QString &);
  void updateTest (bool);
  void updateTest ();

  void addColorization ();
  void removeColorization ();
  void updateColorizationsList ();

  void browseForSoundFile ();
  void updateWindowDialog(bool how);
  void createOutputWindow ();
  
protected:
  void createDialog ();

  bool isalias;
  cAlias *alias;
  cTrigger *trigger;
  cSession *sess;

  //common widgets
  QHBox *hbComboEdit;
  QLabel *cl, *rcl, *ctl, *gl;
  KLineEdit *cmd;
  KTextEdit *rcmd;
  QComboBox *type;
  QComboBox *groups;
  QButtonGroup *options;
  QCheckBox *check1, *check2, *check3, *check4;
  QGroupBox *testarea;
  KLineEdit *text;
  QLabel *textlabel, *matched;
  QLabel *replacement;
  QListView *variables;
  QPushButton *advanced;
	
  //regexpeditor
  bool KRegExpFound;
  QDialog *regExpDialog;
  QPushButton *editregexp;
	
  //color triggers
  int cnum;
  int fgcolor[MAX_COLORIZATIONS], bgcolor[MAX_COLORIZATIONS];
  QColor fgc[MAX_COLORIZATIONS], bgc[MAX_COLORIZATIONS];
  QString ctype[MAX_COLORIZATIONS];

  QCheckBox *chkiscolor;
  QGroupBox *colorgroup;
  QComboBox *clrtype, *fgselect, *bgselect;
  KColorButton *fgcolsel, *bgcolsel;
  KIntNumInput *backrefno;
  KListView *colorizations;

  QCheckBox *chkrewrite;
  QGroupBox *rewritegroup;
  QComboBox *cbrewritevar;
  KIntNumInput *rewritebackrefno;
  KLineEdit *edrewritetext;
  
  //gagging/relocations
  QCheckBox *chkgag;

  //notification
  QCheckBox *chknotify;

  //prompt detection
  QCheckBox *chkprompt;
  
  //output windows
  QCheckBox *chkwindow, *chkgagoutput;
  QGroupBox *outwindow;
  QComboBox *windowlist;
  QLabel *wll, *wnl;
  QPushButton *createwindow;
  KLineEdit *wname;


#ifdef HAVE_SOUND
  //sound
  QCheckBox *chksound;
  KLineEdit *edsoundname;
#endif

  bool firstUpdate;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgeditaliastrigger.h <==
/***************************************************************************
                          dlgeditaliastrigger.h  -  edit alias/trigger
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne sep 22 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITALIASTRIGGER_H
#define DLGEDITALIASTRIGGER_H

#include <qwidget.h>
#include <kdialogbase.h>

#include <config.h>

//needed to get some #define...
#include "ctrigger.h"

class cAlias;

/**
Editor of one alas or trigger. Modifies itself depending on whether we're
editing an alias or a trigger...
  *@author Tomas Mecir
  */

class QButtonGroup;
class QCheckBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QListView;
class QPushButton;

class KColorButton;
class KGridView;
class KIntNumInput;
class KLineEdit;
class KTextEdit;

class dlgEditAliasTrigger : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditAliasTrigger (cAlias *a, int s, QWidget *parent=0, const char *name=0);
  dlgEditAliasTrigger (cTrigger *t, int s, QWidget *parent=0, const char *name=0);
  ~dlgEditAliasTrigger ();
  bool showMe ();
protected slots:
  void updateEditButton (const QString &comboText);
  void editRegExp ();
  void updateTest (const QString &);
  void updateTest (bool);
  void updateTest ();

  void addColorization ();
  void removeColorization ();
  void updateColorizationsList ();

  void browseForSoundFile ();
  void updateWindowDialog(bool how);
  void createOutputWindow ();
  void rewriteChanged (bool val);

protected:
  void createDialog ();

  bool isalias;
  cAlias *alias;
  cTrigger *trigger;
  int sess;

  //common widgets
  QHBox *hbComboEdit;
  QLabel *cl, *rcl, *cndl, *ctl, *gl;
  KLineEdit *cmd;
  KTextEdit *rcmd;
  QComboBox *type;
  QComboBox *groups;
  QButtonGroup *options;
  QCheckBox *check1, *check2, *check3, *check4, *check5;
  QGroupBox *testarea;
  KLineEdit *text;
  KLineEdit *condition;
  QLabel *textlabel, *matched;
  QLabel *replacement;
  QListView *variables;
  QPushButton *advanced;
	
  //regexpeditor
  bool KRegExpFound;
  QDialog *regExpDialog;
  QPushButton *editregexp;
	
  //color triggers
  int cnum;
  int fgcolor[MAX_COLORIZATIONS], bgcolor[MAX_COLORIZATIONS];
  QColor fgc[MAX_COLORIZATIONS], bgc[MAX_COLORIZATIONS];
  QString ctype[MAX_COLORIZATIONS];

  QCheckBox *chkiscolor;
  QGroupBox *colorgroup;
  QComboBox *clrtype, *fgselect, *bgselect;
  KColorButton *fgcolsel, *bgcolsel;
  KIntNumInput *backrefno;
  KListView *colorizations;

  QCheckBox *chkrewrite;
  QGroupBox *rewritegroup;
  QComboBox *cbrewritevar;
  KIntNumInput *rewritebackrefno;
  KLineEdit *edrewritetext;
  
  //gagging/relocations
  QCheckBox *chkgag;

  //notification
  QCheckBox *chknotify;

  //prompt detection
  QCheckBox *chkprompt;
  
  //output windows
  QCheckBox *chkwindow, *chkgagoutput;
  QGroupBox *outwindow;
  QComboBox *windowlist;
  QLabel *wll, *wnl;
  QPushButton *createwindow;
  KLineEdit *wname;


#ifdef HAVE_SOUND
  //sound
  QCheckBox *chksound;
  KLineEdit *edsoundname;
#endif

  bool firstUpdate;
};

#endif
